@@ -46,7 +46,7 @@
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "1.8.2"
+#define OATH_VERSION "1.10.0"
 
 /**
  * OATH_VERSION_NUMBER
@@ -56,7 +56,7 @@
  * this symbol will have the value 0x01020300.  The last two digits
  * are only used between public releases, and will otherwise be 00.
  */
-#define OATH_VERSION_NUMBER 0x01080200
+#define OATH_VERSION_NUMBER 0x010a0000
 
 /**
  * oath_rc:
@@ -214,6 +214,28 @@ oath_totp_validate_callback (const char *secret,
 			     oath_validate_strcmp_function strcmp_otp,
 			     void *strcmp_handle);
 
+extern OATHAPI int
+oath_totp_validate2 (const char *secret,
+		     size_t secret_length,
+		     time_t now,
+		     unsigned time_step_size,
+		     time_t start_offset,
+		     size_t window,
+		     int *window_pos,
+		     const char *otp);
+
+extern OATHAPI int
+oath_totp_validate2_callback (const char *secret,
+			      size_t secret_length,
+			      time_t now,
+			      unsigned time_step_size,
+			      time_t start_offset,
+			      unsigned digits,
+			      size_t window,
+			      int *otp_pos,
+			      oath_validate_strcmp_function strcmp_otp,
+			      void *strcmp_handle);
+
 /* Usersfile */
 
 extern OATHAPI int
